BlockInfo class
Info about a block
- Available extensions
Constructors
-
BlockInfo({List<
int> ? hash, List<int> ? prevHash, int? height, int? nBits, Int64? timestamp, Int64? blockSize, Int64? numTxs, Int64? numInputs, Int64? numOutputs, Int64? sumInputSats, Int64? sumCoinbaseOutputSats, Int64? sumNormalOutputSats, Int64? sumBurnedSats, bool? isFinal}) -
factory
-
BlockInfo.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- BlockInfo.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- blockSize ↔ Int64
-
Block size of this block in bytes (including headers etc.)
getter/setter pair
-
hash
↔ List<
int> -
Hash (little-endian)
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- height ↔ int
-
Height in the chain
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFinal ↔ bool
-
Whether the block has been finalized by Avalanche
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - nBits ↔ int
-
nBits field encoding the target
getter/setter pair
- numInputs ↔ Int64
-
Total number of tx inputs in block (including coinbase)
getter/setter pair
- numOutputs ↔ Int64
-
Total number of tx output in block (including coinbase)
getter/setter pair
- numTxs ↔ Int64
-
Number of txs in this block
getter/setter pair
-
prevHash
↔ List<
int> -
Hash of the previous block (little-endian)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sumBurnedSats ↔ Int64
-
Total number of satoshis burned using OP_RETURN
getter/setter pair
- sumCoinbaseOutputSats ↔ Int64
-
Block reward for this block
getter/setter pair
- sumInputSats ↔ Int64
-
Total number of satoshis spent by tx inputs
getter/setter pair
- sumNormalOutputSats ↔ Int64
-
Total number of satoshis in non-coinbase tx outputs
getter/setter pair
- timestamp ↔ Int64
-
Timestamp field of the block
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBlockSize(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHash(
) → void -
clearHeight(
) → void -
clearIsFinal(
) → void -
clearNBits(
) → void -
clearNumInputs(
) → void -
clearNumOutputs(
) → void -
clearNumTxs(
) → void -
clearPrevHash(
) → void -
clearSumBurnedSats(
) → void -
clearSumCoinbaseOutputSats(
) → void -
clearSumInputSats(
) → void -
clearSumNormalOutputSats(
) → void -
clearTimestamp(
) → void -
clone(
) → BlockInfo - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(BlockInfo)) → BlockInfo -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → BlockInfo - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBlockSize(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHash(
) → bool -
hasHeight(
) → bool -
hasIsFinal(
) → bool -
hasNBits(
) → bool -
hasNumInputs(
) → bool -
hasNumOutputs(
) → bool -
hasNumTxs(
) → bool -
hasPrevHash(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSumBurnedSats(
) → bool -
hasSumCoinbaseOutputSats(
) → bool -
hasSumInputSats(
) → bool -
hasSumNormalOutputSats(
) → bool -
hasTimestamp(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → BlockInfo -
getDefault(
) → BlockInfo