finalizationTimeoutSecs property

  1. @TagNumber.new(3)
Int64 get finalizationTimeoutSecs

Waits for finalization of the transaction before returning the request, for up to the given seconds. Set to 0 to not wait at all and return right after broadcast.

Implementation

@$pb.TagNumber(3)
$fixnum.Int64 get finalizationTimeoutSecs => $_getI64(2);
  1. @TagNumber.new(3)
set finalizationTimeoutSecs (Int64 value)

Implementation

@$pb.TagNumber(3)
set finalizationTimeoutSecs($fixnum.Int64 value) => $_setInt64(2, value);