nextStart property

  1. @TagNumber.new(2)
List<int> get nextStart

Group that if specified as start will give us the next groups, or empty if groups have been exausted.

Implementation

@$pb.TagNumber(2)
$core.List<$core.int> get nextStart => $_getN(1);
  1. @TagNumber.new(2)
set nextStart (List<int> value)

Implementation

@$pb.TagNumber(2)
set nextStart($core.List<$core.int> value) => $_setBytes(1, value);