isInvalid property
Whether the validation rules have been violated for this section
Implementation
@$pb.TagNumber(5)
$core.bool get isInvalid => $_getBF(4);
Implementation
@$pb.TagNumber(5)
set isInvalid($core.bool value) => $_setBool(4, value);
Whether the validation rules have been violated for this section
@$pb.TagNumber(5)
$core.bool get isInvalid => $_getBF(4);
@$pb.TagNumber(5)
set isInvalid($core.bool value) => $_setBool(4, value);