block property
Which block this tx is in, or None, if in the mempool
Implementation
@$pb.TagNumber(8)
BlockMetadata get block => $_getN(5);
Implementation
@$pb.TagNumber(8)
set block(BlockMetadata value) => $_setField(8, value);
Which block this tx is in, or None, if in the mempool
@$pb.TagNumber(8)
BlockMetadata get block => $_getN(5);
@$pb.TagNumber(8)
set block(BlockMetadata value) => $_setField(8, value);