isUnsub property
Set this to true to unsubscribe from the event.
Implementation
@$pb.TagNumber(1)
$core.bool get isUnsub => $_getBF(0);
Implementation
@$pb.TagNumber(1)
set isUnsub($core.bool value) => $_setBool(0, value);
Set this to true to unsubscribe from the event.
@$pb.TagNumber(1)
$core.bool get isUnsub => $_getBF(0);
@$pb.TagNumber(1)
set isUnsub($core.bool value) => $_setBool(0, value);