BlockMsgType class

Type of message for the block

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) BlockMsgType?

Constants

BLK_CONNECTED → const BlockMsgType
Block connected to the blockchain
BLK_DISCONNECTED → const BlockMsgType
Block disconnected from the blockchain
BLK_FINALIZED → const BlockMsgType
Block has been finalized by Avalanche
BLK_INVALIDATED → const BlockMsgType
Block has been invalidated by Avalanche
values → const List<BlockMsgType>