SlpTokenType class

SLP token type

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) SlpTokenType?

Constants

SLP_TOKEN_TYPE_FUNGIBLE → const SlpTokenType
SLP V1 token type
SLP_TOKEN_TYPE_MINT_VAULT → const SlpTokenType
SLP V2 mint vault token type
SLP_TOKEN_TYPE_NFT1_CHILD → const SlpTokenType
NFT1 child token type
SLP_TOKEN_TYPE_NFT1_GROUP → const SlpTokenType
NFT1 group token type
SLP_TOKEN_TYPE_NONE → const SlpTokenType
Unknown "0" token type
values → const List<SlpTokenType>