TokenStatus class

Status of a token tx

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) TokenStatus?

Constants

TOKEN_STATUS_NON_TOKEN → const TokenStatus
Tx involves no tokens whatsover, i.e. neither any burns nor any failed parsing/coloring or any tokens being created / moved.
TOKEN_STATUS_NORMAL → const TokenStatus
Tx involves tokens but no unintentional burns or failed parsings/colorings
TOKEN_STATUS_NOT_NORMAL → const TokenStatus
Tx involves tokens but contains unintentional burns or failed parsings/colorings
values → const List<TokenStatus>