TxFinalizationReasonType class

Type of tx finalization

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) TxFinalizationReasonType?

Constants

TX_FINALIZATION_REASON_POST_CONSENSUS → const TxFinalizationReasonType
The transaction is finalized by post-consensus
TX_FINALIZATION_REASON_PRE_CONSENSUS → const TxFinalizationReasonType
The transaction is finalized by pre-consensus
values → const List<TxFinalizationReasonType>