LokadIdEndpoint class

Endpoint for querying lokad ID data

Inheritance

Constructors

LokadIdEndpoint(FailoverProxy proxy, {required String lokadId})

Properties

hashCode int
The hash code for this object.
no setterinherited
lokadId String
final
proxy FailoverProxy
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmedTxs({int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get confirmed transactions for this lokad ID
history({int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get transaction history for this lokad ID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unconfirmedTxs() Future<TxHistoryPage>
Get unconfirmed transactions for this lokad ID
utxos() Future<UtxosResponse>
Get UTXOs for this lokad ID

Operators

operator ==(Object other) bool
The equality operator.
inherited