PluginEndpoint class

Endpoint for querying plugin data

Inheritance

Constructors

PluginEndpoint(FailoverProxy proxy, {required String pluginName})

Properties

hashCode int
The hash code for this object.
no setterinherited
pluginName String
final
proxy FailoverProxy
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmedTxs(String groupHex, {int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get confirmed transactions for a plugin group
groups({String? prefixHex, String? startHex, int? pageSize}) Future<PluginGroups>
Get all groups for this plugin
history(String groupHex, {int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get transaction history for a plugin group
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unconfirmedTxs(String groupHex) Future<TxHistoryPage>
Get unconfirmed transactions for a plugin group
utxos(String groupHex) Future<UtxosResponse>
Get UTXOs for a plugin group

Operators

operator ==(Object other) bool
The equality operator.
inherited