TokenIdEndpoint class

Endpoint for querying token ID data

Inheritance

Constructors

TokenIdEndpoint(FailoverProxy proxy, {required String tokenId})

Properties

hashCode int
The hash code for this object.
no setterinherited
proxy FailoverProxy
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenId String
final

Methods

confirmedTxs({int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get confirmed transactions for this token
history({int page = 0, int pageSize = 10}) Future<TxHistoryPage>
Get transaction history for this token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unconfirmedTxs() Future<TxHistoryPage>
Get unconfirmed transactions for this token
utxos() Future<UtxosResponse>
Get UTXOs for this token

Operators

operator ==(Object other) bool
The equality operator.
inherited