chronik/failover_proxy library

Classes

Endpoint
A pair of Chronik HTTP and WebSocket endpoint urls
FailoverProxy
Handles the networking to Chronik Endpoints, including cycling through both types of endpoints.

Extensions

EndpointPatterns on Endpoint
Adds pattern-matching-related methods to Endpoint.

Constants

kWebsocketTimeout → const Duration

Functions

appendWsUrls(List<String> urls) List<Endpoint>
Converts an array of chronik http/https urls into websocket equivalents and combines them into an object array