AllServersFailedException class

Exception thrown when all failover servers have been exhausted

Inheritance

Constructors

AllServersFailedException(String message, {required List<String> failedServers})

Properties

failedServers List<String>
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError Object?
finalinherited
originalStackTrace StackTrace?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited