Block class

Block data for in-node chronik

Available extensions
Annotations
  • @freezed

Constructors

Block({required BlockInfo blockInfo})
Block.fromProto(Block proto)
factory

Properties

blockInfo BlockInfo
Contains the blockInfo object defined above
final
copyWith → $BlockCopyWith<Block>
Create a copy of Block with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>() → TResult

Available on Block, provided by the BlockPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>() → TResult?

Available on Block, provided by the BlockPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({required TResult orElse()}) → TResult

Available on Block, provided by the BlockPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({required TResult orElse()}) → TResult

Available on Block, provided by the BlockPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>() → TResult

Available on Block, provided by the BlockPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>() → TResult?

Available on Block, provided by the BlockPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited