BlockTxsResponse class

Response for block transactions query

Constructors

BlockTxsResponse({required int page, required int pageSize, required List<Tx> txs})

Properties

hashCode int
The hash code for this object.
no setterinherited
page int
final
pageSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txs List<Tx>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited