BroadcastResponse class

Response for broadcast transaction

Available extensions
Annotations
  • @freezed

Constructors

BroadcastResponse({required String txid})

Properties

copyWith → $BroadcastResponseCopyWith<BroadcastResponse>
Create a copy of BroadcastResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txid String
final

Methods

map<TResult extends Object?>() → TResult

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>() → TResult?

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({required TResult orElse()}) → TResult

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({required TResult orElse()}) → TResult

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>() → TResult

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>() → TResult?

Available on BroadcastResponse, provided by the BroadcastResponsePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited