ChronikInfo class
- Available extensions
- Annotations
-
- @freezed
Constructors
- ChronikInfo({required String version})
Properties
-
copyWith
→ $ChronikInfoCopyWith<
ChronikInfo> -
Create a copy of ChronikInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on ChronikInfo, provided by the ChronikInfoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited