GenesisInfo class
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- authPubKey → String?
-
final
-
copyWith
→ $GenesisInfoCopyWith<
GenesisInfo> -
Create a copy of GenesisInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- data → String?
-
final
- decimals → int
-
final
- hash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mintVaultScripthash → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenName → String
-
final
- tokenTicker → String
-
final
- url → String
-
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on GenesisInfo, provided by the GenesisInfoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited