PluginEntry class
Plugin data entry
- Available extensions
- Annotations
-
- @freezed
Constructors
-
PluginEntry({required List<
String> groups, required List<String> data})
Properties
-
copyWith
→ $PluginEntryCopyWith<
PluginEntry> -
Create a copy of PluginEntry
with the given fields replaced by the non-null parameter values.
no setterinherited
-
data
→ List<
String> -
Data assigned to the output
final
-
groups
→ List<
String> -
Groups assigned to this output
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> () → TResult -
Available on PluginEntry, provided by the PluginEntryPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on PluginEntry, provided by the PluginEntryPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on PluginEntry, provided by the PluginEntryPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on PluginEntry, provided by the PluginEntryPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on PluginEntry, provided by the PluginEntryPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on PluginEntry, provided by the PluginEntryPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited