ServerException class

Exception thrown when a server is not responsive

Inheritance

Constructors

ServerException(String message, {Object? originalError})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError Object?
finalinherited
originalStackTrace StackTrace?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited