SlpTokenTypeValue enum

Possible SLP token types

Inheritance
Available extensions

Values

fungible → const SlpTokenTypeValue
const SlpTokenTypeValue('SLP_TOKEN_TYPE_FUNGIBLE')
mintVault → const SlpTokenTypeValue
const SlpTokenTypeValue('SLP_TOKEN_TYPE_MINT_VAULT')
nft1Group → const SlpTokenTypeValue
const SlpTokenTypeValue('SLP_TOKEN_TYPE_NFT1_GROUP')
nft1Child → const SlpTokenTypeValue
const SlpTokenTypeValue('SLP_TOKEN_TYPE_NFT1_CHILD')
unknown → const SlpTokenTypeValue
const SlpTokenTypeValue('SLP_TOKEN_TYPE_UNKNOWN')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SlpTokenTypeValue>
A constant List of the values in this enum, in order of their declaration.