TokenFailedParsing class

Failed parsing report for a token

Available extensions
Annotations
  • @freezed

Constructors

TokenFailedParsing({required int pushdataIdx, required String bytes, required String error})

Properties

bytes String
The bytes that failed parsing
final
copyWith → $TokenFailedParsingCopyWith<TokenFailedParsing>
Create a copy of TokenFailedParsing with the given fields replaced by the non-null parameter values.
no setterinherited
error String
Human-readable error message
final
hashCode int
The hash code for this object.
no setterinherited
pushdataIdx int
Index of the pushdata that failed (-1 if whole OP_RETURN failed)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>() → TResult

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>() → TResult?

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({required TResult orElse()}) → TResult

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({required TResult orElse()}) → TResult

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>() → TResult

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>() → TResult?

Available on TokenFailedParsing, provided by the TokenFailedParsingPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited