TokenInfo class
- Available extensions
- Annotations
-
- @freezed
Constructors
- TokenInfo({required String tokenId, required TokenType tokenType, required GenesisInfo genesisInfo, required int timeFirstSeen, BlockMetadata? block})
- TokenInfo.fromProto(TokenInfo proto)
-
factory
Properties
- block → BlockMetadata?
-
final
-
copyWith
→ $TokenInfoCopyWith<
TokenInfo> -
Create a copy of TokenInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- genesisInfo → GenesisInfo
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeFirstSeen → int
-
final
- tokenId → String
-
final
- tokenType → TokenType
-
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on TokenInfo, provided by the TokenInfoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on TokenInfo, provided by the TokenInfoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TokenInfo, provided by the TokenInfoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TokenInfo, provided by the TokenInfoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on TokenInfo, provided by the TokenInfoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on TokenInfo, provided by the TokenInfoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited