TokenTxType enum

Token transaction type

Inheritance
Available extensions

Values

none → const TokenTxType
const TokenTxType('NONE')
unknown → const TokenTxType
const TokenTxType('UNKNOWN')
genesis → const TokenTxType
const TokenTxType('GENESIS')
send → const TokenTxType
const TokenTxType('SEND')
mint → const TokenTxType
const TokenTxType('MINT')
burn → const TokenTxType
const TokenTxType('BURN')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TokenTxType>
A constant List of the values in this enum, in order of their declaration.