TokenType class sealed

Available extensions
Annotations
  • @freezed

Constructors

TokenType.alp({required AlpTokenTypeValue type, required int number})
const
factory
TokenType.slp({required SlpTokenTypeValue type, required int number})
const
factory
TokenType.unknown()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult slp(SlpTokenType value), required TResult alp(AlpTokenType value), required TResult unknown(UnknownTokenType value)}) → TResult

Available on TokenType, provided by the TokenTypePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? slp(SlpTokenType value)?, TResult? alp(AlpTokenType value)?, TResult? unknown(UnknownTokenType value)?}) → TResult?

Available on TokenType, provided by the TokenTypePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult slp(SlpTokenType value)?, TResult alp(AlpTokenType value)?, TResult unknown(UnknownTokenType value)?, required TResult orElse()}) → TResult

Available on TokenType, provided by the TokenTypePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult slp(SlpTokenTypeValue type, int number)?, TResult alp(AlpTokenTypeValue type, int number)?, TResult unknown()?, required TResult orElse()}) → TResult

Available on TokenType, provided by the TokenTypePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult slp(SlpTokenTypeValue type, int number), required TResult alp(AlpTokenTypeValue type, int number), required TResult unknown()}) → TResult

Available on TokenType, provided by the TokenTypePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? slp(SlpTokenTypeValue type, int number)?, TResult? alp(AlpTokenTypeValue type, int number)?, TResult? unknown()?}) → TResult?

Available on TokenType, provided by the TokenTypePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited