TxInput class

Transaction input

Available extensions
Annotations
  • @freezed

Constructors

TxInput({required OutPoint prevOut, required String inputScript, required BigInt sats, required int sequenceNo, String? outputScript, Token? token, PluginEntries? plugins})

Properties

copyWith → $TxInputCopyWith<TxInput>
Create a copy of TxInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inputScript String
Input script (unlocking script)
final
outputScript String?
Output script of the output being spent
final
plugins PluginEntries?
Plugin data attached to this input
final
prevOut OutPoint
Previous output being spent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sats BigInt
Value of the output being spent (satoshis)
final
sequenceNo int
Sequence number
final
token Token?
Token value attached to this input
final

Methods

map<TResult extends Object?>() → TResult

Available on TxInput, provided by the TxInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>() → TResult?

Available on TxInput, provided by the TxInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({required TResult orElse()}) → TResult

Available on TxInput, provided by the TxInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({required TResult orElse()}) → TResult

Available on TxInput, provided by the TxInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>() → TResult

Available on TxInput, provided by the TxInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>() → TResult?

Available on TxInput, provided by the TxInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited