TxMsgType enum

Transaction message type from WebSocket

Inheritance
Available extensions

Values

addedToMempool → const TxMsgType
const TxMsgType('TX_ADDED_TO_MEMPOOL')
removedFromMempool → const TxMsgType
const TxMsgType('TX_REMOVED_FROM_MEMPOOL')
confirmed → const TxMsgType
const TxMsgType('TX_CONFIRMED')
finalized → const TxMsgType
const TxMsgType('TX_FINALIZED')
invalidated → const TxMsgType
const TxMsgType('TX_INVALIDATED')
unknown → const TxMsgType
const TxMsgType('UNRECOGNIZED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TxMsgType>
A constant List of the values in this enum, in order of their declaration.