UtxosResponse class
Response for UTXO query
- Available extensions
- Annotations
-
- @freezed
Constructors
-
UtxosResponse({required List<
Utxo> utxos})
Properties
-
copyWith
→ $UtxosResponseCopyWith<
UtxosResponse> -
Create a copy of UtxosResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
utxos
→ List<
Utxo> -
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on UtxosResponse, provided by the UtxosResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited