WsConfig class

WebSocket configuration

Constructors

WsConfig({void onMessage(WsMsgClient)?, void onConnect()?, void onReconnect(Object error)?, bool keepAlive = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
keepAlive bool
Whether to keep the connection alive with periodic pings
final
onConnect → void Function()?
Called when WebSocket connects
final
onMessage → void Function(WsMsgClient)?
Called when a WebSocket message is received
final
onReconnect → void Function(Object error)?
Called before a reconnection attempt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited