WsMsgBlockClient class

Block message from WebSocket

Inheritance

Constructors

WsMsgBlockClient({required BlockMsgType msgType, required String blockHash, required int blockHeight, required Int64 blockTimestamp, CoinbaseData? coinbaseData})

Properties

blockHash String
final
blockHeight int
final
blockTimestamp → Int64
final
coinbaseData CoinbaseData?
final
hashCode int
The hash code for this object.
no setterinherited
msgType BlockMsgType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited