WsSubScriptClient class
WebSocket subscription for a script/address
- Available extensions
- Annotations
-
- @freezed
Constructors
- WsSubScriptClient({required String scriptType, required String payload})
Properties
-
copyWith
→ $WsSubScriptClientCopyWith<
WsSubScriptClient> -
Create a copy of WsSubScriptClient
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → String
-
Payload for the given script type:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptType → String
-
Script type to subscribe to ("p2pkh", "p2sh", "p2pk", "other")
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on WsSubScriptClient, provided by the WsSubScriptClientPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited