DecodedAddress class
Represents a decoded cash address with its components
Constructors
- DecodedAddress({required String prefix, required AddressType type, required String hash})
Properties
- hash → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- prefix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AddressType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override