nextStart property
Group that if specified as start will give us the next groups,
or empty if groups have been exausted.
Implementation
@$pb.TagNumber(2)
$core.List<$core.int> get nextStart => $_getN(1);
Group that if specified as start will give us the next groups,
or empty if groups have been exausted.
@$pb.TagNumber(2)
$core.List<$core.int> get nextStart => $_getN(1);