TokenEntry class
Token involved in a transaction
- Available extensions
Constructors
-
TokenEntry({String? tokenId, TokenType? tokenType, TokenTxType? txType, String? groupTokenId, bool? isInvalid, String? burnSummary, Iterable<
TokenFailedColoring> ? failedColorings, String? actualBurnAtoms, Int64? intentionalBurnAtoms, bool? burnsMintBatons}) -
factory
-
TokenEntry.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- TokenEntry.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- actualBurnAtoms ↔ String
-
Number of actually burned tokens (as decimal integer
string, e.g. "2000"; in atoms aka base tokens).
This is because burns can exceed the 64-bit range of
values and protobuf doesn't have a nice type to encode this.
getter/setter pair
- burnsMintBatons ↔ bool
-
Whether any mint batons have been burned of this token
getter/setter pair
- burnSummary ↔ String
-
Human-readable error message of why this entry burned tokens
getter/setter pair
-
failedColorings
→ PbList<
TokenFailedColoring> -
Human-readable error messages of why colorings failed
no setter
- groupTokenId ↔ String
-
For NFT1 Child tokens: group ID
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- intentionalBurnAtoms ↔ Int64
-
Burn amount (in atoms aka base tokens) the user explicitly opted into
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - isInvalid ↔ bool
-
Whether the validation rules have been violated for this section
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenId ↔ String
-
Hex token_id (in big-endian, like usually displayed to users) of the token.
This is not
bytesbecause SLP and ALP use different endiannes, so to avoid this we use hex, which conventionally implies big-endian in a bitcoin context.getter/setter pair - tokenType ↔ TokenType
-
Token type of the token
getter/setter pair
- txType ↔ TokenTxType
-
Tx type of the token; NONE if there's no section that introduced it (e.g. in an accidental burn)
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearActualBurnAtoms(
) → void -
clearBurnsMintBatons(
) → void -
clearBurnSummary(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGroupTokenId(
) → void -
clearIntentionalBurnAtoms(
) → void -
clearIsInvalid(
) → void -
clearTokenId(
) → void -
clearTokenType(
) → void -
clearTxType(
) → void -
clone(
) → TokenEntry - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(TokenEntry)) → TokenEntry -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → TokenEntry - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureTokenType(
) → TokenType -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasActualBurnAtoms(
) → bool -
hasBurnsMintBatons(
) → bool -
hasBurnSummary(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGroupTokenId(
) → bool -
hasIntentionalBurnAtoms(
) → bool -
hasIsInvalid(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasTokenId(
) → bool -
hasTokenType(
) → bool -
hasTxType(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → TokenEntry -
getDefault(
) → TokenEntry