TokenTxType class
SLP/ALP tx type
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → TokenTxType?
Constants
- BURN → const TokenTxType
- BURN tx
- GENESIS → const TokenTxType
- GENESIS tx
- MINT → const TokenTxType
- MINT tx
- NONE → const TokenTxType
- No tx type, e.g. when input tokens are burned
- SEND → const TokenTxType
- SEND tx
- UNKNOWN → const TokenTxType
- Unknown tx type, i.e. for unknown token types
-
values
→ const List<
TokenTxType>