TxMsgType class
Type of message for a tx
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- TX_ADDED_TO_MEMPOOL → const TxMsgType
- Tx added to the mempool
- TX_CONFIRMED → const TxMsgType
- Tx confirmed in a block
- TX_FINALIZED → const TxMsgType
- Tx finalized by Avalanche
- TX_INVALIDATED → const TxMsgType
- Tx invalidated by Avalanche
- TX_REMOVED_FROM_MEMPOOL → const TxMsgType
- Tx removed from the mempool
-
values
→ const List<
TxMsgType>