chronik/types library

Type definitions for Chronik client

Classes

AlpTokenType
ALP token type
Block
Block on the blockchain
BlockchainInfo
Info about the state of the blockchain.
BlockHeader
Header on the blockchain
BlockHeaders
Range of headers
BlockInfo
Info about a block
BlockMetadata
Data about a block which a Tx is in.
Blocks
Range of blocks
BlockTxsResponse
Response for block transactions query
BroadcastAndFinalizeResponse
Response for broadcast and finalize transaction
BroadcastResponse
Response for broadcast transaction
BroadcastTxRequest
Broadcast a single tx
BroadcastTxResponse
Response of broadcasting the tx
BroadcastTxsRequest
Broadcast multiple txs. If one of the txs fails token validation, the entire batch will not be broadcast.
BroadcastTxsResponse
Response of broadcasting txs
ChronikInfo
Info about the chronik software this server is running
CoinbaseData
The relevant coinbase data
ConfirmedTxsResponse
Response for confirmed transactions query
Empty
Empty msg without any data
Error
Error message returned from our APIs.
GenesisInfo
Genesis info found in GENESIS txs of tokens
GroupsResponse
Response for plugin groups query
HistoryResponse
Response for script/address history query
MsgBlock
Block got connected, disconnected, finalized, invalidated, etc.
MsgTx
Tx got added to/removed from mempool, or confirmed in a block, etc.
OutPoint
COutPoint, points to a coin being spent by an input.
PluginEntry
Data attached by a plugin to an output
PluginGroup
Data about a plugin group
PluginGroups
List of plugin groups
RawTx
Raw serialized tx.
ScriptUtxo
UTXO of a script.
ScriptUtxos
List of UTXOs of a script
SlpTokenType
SLP token type
SpentBy
Points to an input spending a coin.
Token
Token coloring an input or output
TokenEntry
Token involved in a transaction
TokenFailedColoring
A report of a failed coloring attempt of SLP/ALP. This should always indicate something went wrong when building the tx.
TokenFailedParsing
A report of a failed parsing attempt of SLP/ALP. This should always indicate something went wrong when building the tx.
TokenInfo
Info about a token
TokenStatus
Status of a token tx
TokenTxType
SLP/ALP tx type
TokenType
SLP/ALP token type
Tx
Details about a transaction
TxFinalizationReason
The reason that caused a tx to finalize
TxFinalizationReasonType
Type of tx finalization
TxHistoryPage
Page with txs
TxInput
CTxIn, spends a coin.
TxMsgType
Type of message for a tx
TxOutput
CTxOut, creates a new coin.
UnconfirmedTxsResponse
Response for unconfirmed transactions query
Utxo
UTXO, but with a script attached.
Utxos
List of UTXOs
UtxosResponse
Response for UTXO query
ValidateRawTxResponse
Response for transaction validation
WsConfig
WebSocket configuration
WsErrorMsg
Error message from WebSocket
WsMsg
Message coming from the WebSocket
WsMsgBlockClient
Block message from WebSocket
WsMsgClient
WebSocket message from server
WsMsgTxClient
Transaction message from WebSocket
WsPlugin
Subscription to a group assigned by a plugin to outputs.
WsSub
Subscription to WebSocket updates.
WsSubBlocks
Subscription to blocks. They will be sent any time a block got connected, disconnected or finalized.
WsSubLokadId
Subscription to a LOKAD ID. They will be sent every time a tx matches the given LOKAD ID in one of the following ways:
WsSubScript
Subscription to a script. They will be sent every time a tx spending the given script or sending to the given script has been added to/removed from the mempool, or confirmed in a block.
WsSubscriptions
WebSocket subscriptions state
WsSubTokenId
Subscription to a token ID. They will be sent every time a tx spending or sending tokens with the token ID.
WsSubTxId
Subscription to a txid. They will be sent every time a tx status confirmation changes.
WsSubTxs
Subscription to all txs.

Enums

BlockMsgType
Block message type from WebSocket
ConnectionStrategy
Connection strategy for the Chronik client
ScriptType
Type of script/address
TokenType_TokenType
WsMsg_MsgType
WsSub_SubType

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.

Typedefs

BlockchainInfoResponse = BlockchainInfo
Response containing blockchain information
BlockResponse = Block
Response containing block information
ChronikInfoResponse = ChronikInfo
Response containing Chronik server information
TokenInfoResponse = TokenInfo
Response containing token information
TxResponse = Tx
Response containing transaction details
UtxoResponse = Utxo
Response containing UTXO information

Exceptions / Errors

AllServersFailedException
Exception thrown when all failover servers have been exhausted
ChronikException
Exception thrown by Chronik client
ServerException
Exception thrown when a server is not responsive
ValidationException
Exception thrown when validation fails