ScriptUtxo class
Unspent transaction output
- Available extensions
- Annotations
-
- @freezed
Constructors
- ScriptUtxo({required OutPoint outpoint, required int blockHeight, required bool isCoinbase, required BigInt sats, required bool isFinal, Token? token, PluginEntries? plugins})
Properties
- blockHeight → int
-
Block height (-1 if in mempool)
final
-
copyWith
→ $ScriptUtxoCopyWith<
ScriptUtxo> -
Create a copy of ScriptUtxo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCoinbase → bool
-
Whether this is a coinbase UTXO
final
- isFinal → bool
-
Whether finalized by Avalanche
final
- outpoint → OutPoint
-
Output reference
final
- plugins → PluginEntries?
-
Plugin data attached to this UTXO
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sats → BigInt
-
Value in satoshis
final
- token → Token?
-
Token value attached to this UTXO
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on ScriptUtxo, provided by the ScriptUtxoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited