TokenEntry class
Token involved in a transaction
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TokenEntry({required String tokenId, required Object tokenType, required TokenTxType txType, required bool isInvalid, required String burnSummary, required List<
TokenFailedColoring> failedColorings, required BigInt actualBurnAtoms, required BigInt intentionalBurnAtoms, required bool burnsMintBatons, String? groupTokenId})
Properties
- actualBurnAtoms → BigInt
-
Number of burned tokens (atoms)
final
- burnsMintBatons → bool
-
Whether any mint batons were burned
final
- burnSummary → String
-
Human-readable burn summary
final
-
copyWith
→ $TokenEntryCopyWith<
TokenEntry> -
Create a copy of TokenEntry
with the given fields replaced by the non-null parameter values.
no setterinherited
-
failedColorings
→ List<
TokenFailedColoring> -
Human-readable error messages for failed colorings
final
- groupTokenId → String?
-
Group token ID (for NFT1 child tokens only)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intentionalBurnAtoms → BigInt
-
User-explicitly opted-in burn amount (atoms)
final
- isInvalid → bool
-
Whether validation rules were violated
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenId → String
-
Hex token ID (big-endian)
final
- tokenType → Object
-
Token type (SLP or ALP)
final
- txType → TokenTxType
-
Transaction type (NONE, GENESIS, SEND, MINT, BURN)
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on TokenEntry, provided by the TokenEntryPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on TokenEntry, provided by the TokenEntryPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TokenEntry, provided by the TokenEntryPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TokenEntry, provided by the TokenEntryPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on TokenEntry, provided by the TokenEntryPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on TokenEntry, provided by the TokenEntryPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited