Tx class
A complete transaction with all details
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Tx({required String txid, required int version, required List<
TxInput> inputs, required List<TxOutput> outputs, required int lockTime, required int timeFirstSeen, required int size, required bool isCoinbase, required List<TokenEntry> tokenEntries, required List<TokenFailedParsing> tokenFailedParsings, required TokenStatus tokenStatus, required bool isFinal, BlockMetadata? block}) - Tx.fromProto(Tx proto)
-
factory
Properties
- block → BlockMetadata?
-
Block metadata (if confirmed)
final
-
copyWith
→ $TxCopyWith<
Tx> -
Create a copy of Tx
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ List<
TxInput> -
Transaction inputs
final
- isCoinbase → bool
-
Whether this is a coinbase transaction
final
- isFinal → bool
-
Whether this transaction is finalized
final
- lockTime → int
-
Lock time
final
-
outputs
→ List<
TxOutput> -
Transaction outputs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Transaction size in bytes
final
- timeFirstSeen → int
-
Time first seen (UNIX timestamp)
final
-
tokenEntries
→ List<
TokenEntry> -
Token entries in this transaction
final
-
tokenFailedParsings
→ List<
TokenFailedParsing> -
Failed token parsing attempts
final
- tokenStatus → TokenStatus
-
Token status
final
- txid → String
-
Transaction ID (big-endian hex)
final
- version → int
-
Transaction version
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on Tx, provided by the TxPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on Tx, provided by the TxPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on Tx, provided by the TxPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on Tx, provided by the TxPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on Tx, provided by the TxPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on Tx, provided by the TxPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited