TxOutput class
Transaction output
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $TxOutputCopyWith<
TxOutput> -
Create a copy of TxOutput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputScript → String
-
Output script (locking script)
final
- plugins → PluginEntries?
-
Plugin data attached to this output
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sats → BigInt
-
Output value (satoshis)
final
- spentBy → OutPoint?
-
Output that spends this output
final
- token → Token?
-
Token value attached to this output
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on TxOutput, provided by the TxOutputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on TxOutput, provided by the TxOutputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TxOutput, provided by the TxOutputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on TxOutput, provided by the TxOutputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on TxOutput, provided by the TxOutputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on TxOutput, provided by the TxOutputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited