Utxo class
- Available extensions
- Annotations
-
- @freezed
Constructors
- Utxo({required OutPoint outpoint, required int blockHeight, required bool isCoinbase, required Int64 sats, required String script, required bool isFinal, Token? token, PluginEntries? plugins})
- Utxo.fromProto(Utxo proto)
-
factory
Properties
- blockHeight → int
-
Which block this UTXO is in, or -1 if in the mempool.
final
-
copyWith
→ $UtxoCopyWith<
Utxo> -
Create a copy of Utxo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCoinbase → bool
-
Whether this is a coinbase UTXO
(make sure it's buried 100 blocks before spending!)
final
- isFinal → bool
-
Is this utxo avalanche finalized
final
- outpoint → OutPoint
-
Outpoint of the UTXO.
final
- plugins → PluginEntries?
-
Plugin data attached to this output
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sats → Int64
-
Value of the UTXO in satoshis
final
- script → String
-
Bytecode of the script of the output
final
- token → Token?
-
Token value attached to this utxo
final
Methods
-
map<
TResult extends Object?> () → TResult -
Available on Utxo, provided by the UtxoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> () → TResult? -
Available on Utxo, provided by the UtxoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on Utxo, provided by the UtxoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({required TResult orElse()}) → TResult -
Available on Utxo, provided by the UtxoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> () → TResult -
Available on Utxo, provided by the UtxoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> () → TResult? -
Available on Utxo, provided by the UtxoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited