WsMsgClient class sealed
WebSocket message from server
- Available extensions
- Annotations
-
- @freezed
Constructors
- WsMsgClient.block({required BlockMsgType msgType, required String blockHash, required int blockHeight, required Int64 blockTimestamp, CoinbaseData? coinbaseData})
-
constfactory
- WsMsgClient.error(Error error)
-
constfactory
- WsMsgClient.tx({required TxMsgType msgType, required String txid, TxFinalizationReasonType? finalizationReasonType})
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult error(WsErrorMsg value), required TResult block(WsMsgBlockClient value), required TResult tx(WsMsgTxClient value)}) → TResult -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? error(WsErrorMsg value)?, TResult? block(WsMsgBlockClient value)?, TResult? tx(WsMsgTxClient value)?}) → TResult? -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult error(WsErrorMsg value)?, TResult block(WsMsgBlockClient value)?, TResult tx(WsMsgTxClient value)?, required TResult orElse()}) → TResult -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult error(Error error)?, TResult block(BlockMsgType msgType, String blockHash, int blockHeight, Int64 blockTimestamp, CoinbaseData? coinbaseData)?, TResult tx(TxMsgType msgType, String txid, TxFinalizationReasonType? finalizationReasonType)?, required TResult orElse()}) → TResult -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult error(Error error), required TResult block(BlockMsgType msgType, String blockHash, int blockHeight, Int64 blockTimestamp, CoinbaseData? coinbaseData), required TResult tx(TxMsgType msgType, String txid, TxFinalizationReasonType? finalizationReasonType)}) → TResult -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? error(Error error)?, TResult? block(BlockMsgType msgType, String blockHash, int blockHeight, Int64 blockTimestamp, CoinbaseData? coinbaseData)?, TResult? tx(TxMsgType msgType, String txid, TxFinalizationReasonType? finalizationReasonType)?}) → TResult? -
Available on WsMsgClient, provided by the WsMsgClientPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited