WsSubscriptions class
WebSocket subscriptions state
Constructors
Properties
- blocks ↔ bool
-
Whether subscribed to all blocks
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lokadIds
→ Set<
String> -
Subscriptions to lokad IDs
final
-
plugins
→ Set<
String> -
Subscriptions to plugins {name}/{groupHex}
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scripts
→ Set<
String> -
Subscriptions to scripts {type}/{payload}
final
-
tokenIds
→ Set<
String> -
Subscriptions to token IDs
final
-
txids
→ Set<
String> -
Subscriptions to transaction IDs
final
- txs ↔ bool
-
Whether subscribed to all transactions
getter/setter pair
Methods
-
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited