ecashaddr/cashaddr library
Constants
-
validPrefixes
→ const List<
String> - All valid address prefixes Note that as of 2.0.0 we do not validate against these prefixes However we do use them to guess prefix for prefixless addrs
Functions
-
decodeCashAddress(
String address) → DecodedAddress - Decodes the given address into its constituting prefix, type and hash.
-
encodeCashAddress(
String prefix, AddressType type, dynamic hash) → String - Encodes a hash from a given type into an eCash address with the given prefix.
-
getOutputScriptFromTypeAndHash(
AddressType type, String hash) → String - Get output script from type and hash
-
getTypeAndHashFromOutputScript(
String outputScript) → TypeAndHash - Get type and hash from an outputScript