ecashaddr/convert_bits library
Functions
-
convertBits(
Uint8List data, int from, int to, {bool strictMode = false}) → Uint8List - Converts an array of integers made up of 'from' bits into an array of integers made up of 'to' bits. The output array is zero-padded if necessary, unless strict mode is true. Throws a ValidationError if input is invalid. Original by Pieter Wuille: https://github.com/sipa/bech32.